﻿using System;
using System.Data.SqlClient;
using System.Linq;
using System.Windows;
using System.Reflection;
using System.Data;
using System.Collections.ObjectModel;

namespace WpfApp1
{
    public static class Helpers
    {
        public static System.Data.DataTable GetDataAsDataTableFromSQLQuery(string sConString, string sQuery)
        {
            System.Data.DataTable _SQLDataTable = new System.Data.DataTable();

            try
            {
                if (!string.IsNullOrEmpty(sConString))
                {
                    using (System.Data.SqlClient.SqlConnection _SQLConnection = new System.Data.SqlClient.SqlConnection(sConString))
                    {
                        using (SqlCommand _SQLCommand = new SqlCommand(sQuery, _SQLConnection))
                        {
                            try
                            {
                                _SQLCommand.Connection.Open();
                                _SQLCommand.ExecuteNonQuery();

                                using (SqlDataAdapter _SQLDataAdapter = new SqlDataAdapter(_SQLCommand))
                                {
                                    _SQLDataTable.BeginLoadData();
                                    _SQLDataAdapter.Fill(_SQLDataTable);
                                    _SQLDataTable.EndLoadData();
                                }
                            }
                            catch (SqlException ex)
                            {
                                MessageBox.Show(ex.Message, "SQL Error");
                                return null;
                            }
                        }
                    }
                }
                return _SQLDataTable;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Unhandled Error");
                return null;
            }
        }

        public static ObservableCollection<T> DataTableToList<T>(this DataTable table) where T : class, new()
        {
            try
            {
                ObservableCollection<T> list = new ObservableCollection<T>();

                foreach (var row in table.AsEnumerable())
                {
                    T obj = new T();

                    foreach (var prop in obj.GetType().GetProperties())
                    {
                        try
                        {
                            PropertyInfo propertyInfo = obj.GetType().GetProperty(prop.Name);
                            propertyInfo.SetValue(obj, Convert.ChangeType(row[prop.Name], propertyInfo.PropertyType), null);
                        }
                        catch
                        {
                            continue;
                        }
                    }

                    list.Add(obj);
                }

                return list;
            }
            catch
            {
                return null;
            }
        }


        public static DataTable GetDataTableWithRandomData()
        {            
            DataTable dt = new DataTable();

            dt.Columns.Add(new DataColumn("Seriennummer", typeof(String)));
            dt.Columns.Add(new DataColumn("Artikelnummer", typeof(String)));
            dt.Columns.Add(new DataColumn("Vertriebsauftragsnummer", typeof(String)));
            dt.Columns.Add(new DataColumn("Artikelbenennung", typeof(String)));

            dt.Rows.Add("123456", "654321", "229", "Testartikel1");
            dt.Rows.Add("123457", "654322", "228", "Testartikel2");
            dt.Rows.Add("123458", "654323", "227", "Testartikel3");
            dt.Rows.Add("123459", "654324", "226", "Testartikel4");
            dt.Rows.Add("123460", "654325", "225", "Testartikel5");

            return dt;

        }
    }
}
